# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.4.0] - 2021-02-06

### Added:

Initial release into the wild of the code, previously used only internally in BAS

[0.4.0]: https://github.com/JimCircadian/model-ensembler/releases/tag/v0.4.0
